@@ -5,7 +5,7 @@
 
 package Mail::Box::File;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '2.115';
 
 use base 'Mail::Box';
 
@@ -26,7 +26,10 @@ use File::Copy;
 use File::Spec;
 use File::Basename;
 use POSIX ':unistd_h';
-use IO::File ();
+
+# tell() is not available for open(my $fh) on perl versions <= 5.10  So,
+# we need to stick to IO::File syntax.
+use IO::File;
 
 my $windows;
 BEGIN { $windows = $^O =~ m/mswin32|cygwin/i }
@@ -124,15 +127,14 @@ sub create($@)
     $class->moveAwaySubFolder($filename, $subext)
         if -d $filename && defined $subext;
 
-    if(my $create = IO::File->new($filename, 'w'))
-    {   $class->log(PROGRESS => "Created folder $name.");
-        $create->close or return;
-    }
-    else
+    my $create = IO::File->new($filename, 'w');
+    unless($create)
     {   $class->log(WARNING => "Cannot create folder file $name: $!");
         return;
     }
 
+    $class->log(PROGRESS => "Created folder $name.");
+    $create->close or return;
     $class;
 }
 
@@ -347,6 +349,7 @@ sub _write_new($)
     my $new      = IO::File->new($filename, 'w');
     return 0 unless defined $new;
 
+    $new->binmode;
     $_->write($new) foreach @{$args->{messages}};
 
     $new->close or return 0;
@@ -368,7 +371,10 @@ sub _write_replace($)
     my $tmpnew   = $self->tmpNewFolder($filename);
 
     my $new      = IO::File->new($tmpnew, 'w')   or return 0;
+    $new->binmode;
+
     my $old      = IO::File->new($filename, 'r') or return 0;
+    $old->binmode;
 
     my ($reprint, $kept) = (0,0);
 
@@ -397,7 +403,7 @@ sub _write_replace($)
            unless $size == $need;
 
         $new->print($whole);
-        $new->print("\n");
+        $new->print($Mail::Message::crlf_platform ? "\r\n" : "\n");
 
         $message->moveLocation($newbegin - $oldbegin);
         $kept++;
@@ -453,7 +459,6 @@ sub _write_inplace($)
 
     my $mode     = $^O eq 'MSWin32' ? 'a' : 'r+';
     my $filename = $self->filename;
-
     my $old      = IO::File->new($filename, $mode) or return 0;
 
     # Chop the folder after the messages which does not have to change.
