@@ -6,7 +6,7 @@
 use strict;
 package Mail::Box::Thread::Manager;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '2.115';
 
 use base 'Mail::Reporter';
 
@@ -38,11 +38,8 @@ sub init($)
 
 #-------------------------------------------
 
-
 sub folders() { values %{shift->{MBTM_folders}} }
 
-#-------------------------------------------
-
 
 sub includeFolder(@)
 {   my $self = shift;
@@ -63,8 +60,6 @@ sub includeFolder(@)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub removeFolder(@)
 {   my $self = shift;
@@ -89,7 +84,6 @@ sub removeFolder(@)
 
 #-------------------------------------------
 
-
 sub thread($)
 {   my ($self, $message) = @_;
     my $msgid     = $message->messageId;
@@ -128,8 +122,6 @@ sub thread($)
     $thread;
 }
 
-#-------------------------------------------
-
 
 sub threadStart($)
 {   my ($self, $message) = @_;
@@ -161,8 +153,6 @@ sub threadStart($)
     $thread;
 }
 
-#-------------------------------------------
-
 
 sub all()
 {   my $self = shift;
@@ -170,8 +160,6 @@ sub all()
     $self->known;
 }
 
-#-------------------------------------------
-
 
 sub sortedAll(@)
 {   my $self = shift;
@@ -179,16 +167,12 @@ sub sortedAll(@)
     $self->sortedKnown(@_);
 }
 
-#-------------------------------------------
-
 
 sub known()
 {   my $self      = shift->_process_delayed_nodes->_cleanup;
     grep {!defined $_->repliedTo} values %{$self->{MBTM_ids}};
 }
 
-#-------------------------------------------
-
 
 sub sortedKnown(;$$)
 {   my $self    = shift;
@@ -197,8 +181,8 @@ sub sortedKnown(;$$)
  
     # Special care for double keys.
     my %value;
-    push @{$value{$prepare->($_)}}, $_  foreach $self->known; 
-    map { @{$value{$_}} } sort {$compare->($a, $b)} keys %value;
+    push @{$value{$prepare->($_)}}, $_ for $self->known; 
+    map @{$value{$_}}, sort {$compare->($a, $b)} keys %value;
 }
 
 # When a whole folder is removed, many threads can become existing
@@ -238,7 +222,6 @@ sub _cleanup()
 
 #-------------------------------------------
 
-
 sub toBeThreaded($@)
 {   my ($self, $folder) = (shift, shift);
     return $self unless exists $self->{MBTM_folders}{$folder->name};
@@ -246,8 +229,6 @@ sub toBeThreaded($@)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub toBeUnthreaded($@)
 {   my ($self, $folder) = (shift, shift);
@@ -256,8 +237,6 @@ sub toBeUnthreaded($@)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub inThread($)
 {   my ($self, $message) = @_;
